
# THIS FILE IS GENERATED FROM OASYS SETUP.PY
short_version = '1.0.19'
version = '1.0.19'
full_version = '1.0.19'
git_revision = '638a012c57f0f432ba84ef18551e90b2c84f1e69'
release = True

if not release:
    version = full_version
    short_version += ".dev"
